@@ -58,7 +58,7 @@ load_race_session <- function(obj_name = "session", season = get_current_season(
   }
 
   # only cache to tempdir if cache option is set to memory or off (includes filesystem in vector as a fallback error catch)
-  if (getOption("f1dataR.cache") %in% c("memory", "off", "filesystem")) {
+  if (getOption("f1dataR.cache", default = "memory") %in% c("memory", "off", "filesystem")) {
     f1datar_cache <- normalizePath(tempdir(), winslash = "/")
   } else {
     f1datar_cache <- normalizePath(getOption("f1dataR.cache"), winslash = "/")
@@ -69,7 +69,7 @@ load_race_session <- function(obj_name = "session", season = get_current_season(
   }
 
   reticulate::py_run_string("import fastf1")
-  if (get_fastf1_version() >= 3) {
+  if (get_fastf1_version()$major >= 3) {
     reticulate::py_run_string(glue::glue("fastf1.set_log_level('{log_level}')", log_level = log_level))
   }
 
