@@ -29,9 +29,11 @@ plot_fastest <- function(season = get_current_season(), round = 1, session = "R"
     cli::cli_abort("f1dataR::plot_fastest() requires ggplot2 package installation")
   }
   if (lifecycle::is_present(race)) {
-    lifecycle::deprecate_stop("1.4.0", 
-                              "plot_fastest(race)", 
-                              "plot_fastest(round)")
+    lifecycle::deprecate_stop(
+      "1.4.0",
+      "plot_fastest(race)",
+      "plot_fastest(round)"
+    )
     round <- race
   }
 
