@@ -14,7 +14,7 @@ test_that("Lap Load works", {
   expect_equal(laps_2021_1$position[1], "1")
 
   expect_error(load_laps(3050, 3), "`season` must be between 1996 and *")
-  expect_warning(load_laps(2021, race = 1))
+  expect_error(load_laps(2021, race = 1))
 
   # 2021 Spa had very few laps
   laps_short <- load_laps(2021, 12)
